.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        Click :ref:`here <sphx_glr_download_auto_examples_data_plot_specific.py>`     to download the full example code or to run this example in your browser via Binder
    .. rst-class:: sphx-glr-example-title

    .. _sphx_glr_auto_examples_data_plot_specific.py:


===============
Specific images
===============


.. code-block:: default

    import matplotlib.pyplot as plt
    import matplotlib

    from skimage import data

    matplotlib.rcParams['font.size'] = 18








Stereo images
=============


.. code-block:: default



    fig, axes = plt.subplots(1, 2, figsize=(8, 4))
    ax = axes.ravel()

    images = data.stereo_motorcycle()
    ax[0].imshow(images[0])
    ax[1].imshow(images[1])

    fig.tight_layout()
    plt.show()




.. image:: /auto_examples/data/images/sphx_glr_plot_specific_001.png
    :class: sphx-glr-single-img





Faces and non-faces dataset
===========================

A sample of 20 over 200 images is displayed.


.. code-block:: default



    fig, axes = plt.subplots(4, 5, figsize=(20, 20))
    ax = axes.ravel()
    images = data.lfw_subset()
    for i in range(20):
        ax[i].imshow(images[90+i], cmap=plt.cm.gray)
        ax[i].axis('off')
    fig.tight_layout()
    plt.show()



.. image:: /auto_examples/data/images/sphx_glr_plot_specific_002.png
    :class: sphx-glr-single-img






.. rst-class:: sphx-glr-timing

   **Total running time of the script:** ( 0 minutes  1.131 seconds)


.. _sphx_glr_download_auto_examples_data_plot_specific.py:


.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-example


  .. container:: binder-badge

    .. image:: https://mybinder.org/badge_logo.svg
      :target: https://mybinder.org/v2/gh/scikit-image/scikit-image/v0.17.x?filepath=notebooks/auto_examples/data/plot_specific.ipynb
      :width: 150 px


  .. container:: sphx-glr-download sphx-glr-download-python

     :download:`Download Python source code: plot_specific.py <plot_specific.py>`



  .. container:: sphx-glr-download sphx-glr-download-jupyter

     :download:`Download Jupyter notebook: plot_specific.ipynb <plot_specific.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
